package com.hl.demo;

import android.Manifest;
import android.app.Activity;
import android.app.AlertDialog;
import android.content.Intent;
import android.content.res.Configuration;
import android.os.Bundle;
import android.view.View;
import android.widget.Button;
import android.widget.TextView;

import com.hoolai.access.open.fastaccess.channel.FastSdk;
import com.hoolai.access.open.fastaccess.channel.request.EventType;
import com.hoolai.access.open.fastaccess.channel.request.GoodsInfo;
import com.hoolai.access.open.fastaccess.channel.request.PayParams;
import com.hoolai.access.open.fastaccess.channel.request.PlayerInfo;
import com.hoolai.access.open.fastaccess.channel.result.InitResult;
import com.hoolai.access.open.fastaccess.channel.result.LoginResult;
import com.hoolai.access.open.fastaccess.interf.HLAccountListener;
import com.hoolai.access.open.fastaccess.interf.HLPaymentListener;
import com.hoolai.access.open.fastaccess.interf.HLShareListener;
import com.hoolai.access.open.fastaccess.interf.HLSystemListener;
import com.hoolai.access.open.fastaccess.utils.Logger;
import com.hoolai.access.open.fastaccess.utils.ToastUtils;

import java.util.List;

public class MainActivity extends Activity {
    private boolean isInit, isLogin;
    private TextView textview;
    private Button initBtn;
    private String str = "";

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);
        textview = findViewById(R.id.textview);
        initBtn = findViewById(R.id.initBtn);

        //声明系统回调（初始化，退出，版本升级）监听
        FastSdk.hlSystemListener = new HLSystemListener() {
            @Override
            public void onInitSuccess(InitResult initResult) {
                isInit = true;
                Logger.data("fastsdkdemo","初始化成功");
                setText(">>初始化成功");
                initBtn.setVisibility(View.GONE);
            }

            @Override
            public void onInitFailed(String reason) {
                Logger.data("fastsdkdemo","初始化失败:"+reason);
                setText(">>初始化失败");
                initBtn.setVisibility(View.VISIBLE);
            }

            @Override
            public void onCustomExit() {
                Logger.data("fastsdkdemo","弹出游戏的退出界面");
                setText(">>弹出游戏的退出界面");
                new AlertDialog.Builder(MainActivity.this)
                        .setTitle("游戏退出弹窗")
                        .setMessage("我是游戏的弹窗界面哦")
                        .setNegativeButton("取消", null)
                        .setPositiveButton("确定", (dialog, which) -> onExitSuccess(""))
                        .setCancelable(false).show();
            }

            @Override
            public void onExitSuccess(String result) {
                //当前渠道如果有退出界面，触发该回调
                //处理退出逻辑，
                moveTaskToBack(true);
                finish();
                //建议游戏按照下面代码逻辑，退出程序兼容性最好，否则可能会造成oppop、vivo等渠道退出不彻底，导致再次点击启动应用黑屏。
                Intent intent = new Intent(Intent.ACTION_MAIN);
                intent.addCategory(Intent.CATEGORY_HOME);
                intent.setFlags(Intent.FLAG_ACTIVITY_CLEAR_TOP);
                startActivity(intent);
                android.os.Process.killProcess(android.os.Process.myPid());
            }

            @Override
            public void onUpdate(String data) {
                Logger.data("fastsdkdemo","升级：" + data);
            }
        };
        //声明账号回调监听
        FastSdk.hlAccountListener = new HLAccountListener() {
            @Override
            public void onRefreshUser(LoginResult result) {
                //没有小号可忽略
            }

            @Override
            public void onLoginSuccess(LoginResult result) {
                Logger.data("fastsdkdemo","登录成功：" + result);
                setText(">>登录成功：" + result.toString() + "");
                isLogin = true;
            }

            @Override
            public void onLoginFailed(String reason) {
                Logger.data("fastsdkdemo","登录失败:" + reason);
                setText(">>登录失败");
            }

            @Override
            public void onLogout(Object... var1) {
                Logger.data("fastsdkdemo","已登出");
                setText(">>已登出");
                isLogin = false;
            }
        };
        FastSdk.hlPaymentListener = new HLPaymentListener() {
            @Override
            public void onPaySuccess(String result) {
                Logger.data("fastsdkdemo","支付成功 " + result);
                setText(">>支付成功");
            }

            @Override
            public void onPayFailed(String reason) {
                Logger.data("fastsdkdemo","支付失败:" + reason);
                setText(">>支付失败");
            }

            @Override
            public void onQuerySuccess(List<GoodsInfo> list) {
                Logger.data("fastsdkdemo","商品信息获取成功:" + list.toString());
                ProductUtils.showProducts(MainActivity.this, list);
                setText(">>商品信息获取成功");
            }
        };
        FastSdk.hlShareListener = new HLShareListener() {
            @Override
            public void onShareSuccess() {

            }

            @Override
            public void onShareFailed(String s) {

            }
        };
        FastSdk.onCreate(MainActivity.this);
        setText("调用初始化");
    }

    @Override
    protected void onSaveInstanceState(Bundle outState) {
        super.onSaveInstanceState(outState);
        FastSdk.onSaveInstanceState(outState);
    }

    @Override
    protected void onStart() {
        super.onStart();
        FastSdk.onStart(this);
    }

    @Override
    protected void onResume() {
        Logger.data("fastsdkdemo","游戏页面onResume");
        super.onResume();
        FastSdk.onResume(this);
    }

    @Override
    protected void onStop() {
        super.onStop();
        FastSdk.onStop(this);
    }

    @Override
    protected void onPause() {
        super.onPause();
        FastSdk.onPause(this);
    }

    @Override
    protected void onRestart() {
        super.onRestart();
        Logger.data("fastsdkdemo","游戏页面onRestart");
        FastSdk.onRestart(this);
    }

    @Override
    protected void onDestroy() {
        super.onDestroy();
        FastSdk.onDestroy(this);
    }

    @Override
    protected void onNewIntent(Intent intent) {
        super.onNewIntent(intent);
        FastSdk.onNewIntent(intent);
    }

    @Override
    protected void onActivityResult(int requestCode, int resultCode, Intent data) {
        FastSdk.onActivityResult(this, requestCode, resultCode, data);
    }

    @Override
    public void onRequestPermissionsResult(int requestCode, String[] permissions, int[] grantResults) {
        super.onRequestPermissionsResult(requestCode, permissions, grantResults);
        FastSdk.onRequestPermissionsResult(requestCode, permissions, grantResults);
    }

    @Override
    public void onConfigurationChanged(Configuration newConfig) {
        super.onConfigurationChanged(newConfig);
        FastSdk.onConfigurationChanged(this, newConfig, getResources());
    }

    @Override
    public void onBackPressed() {
        setText("调用返回");
        FastSdk.exit();
    }

    public void init(View v){
        setText("调用初始化");
        FastSdk.onCreate(this);
    }

    public void login(View v){
        if (isInit){
            setText("调用登录");
            FastSdk.login();
        }else{
            ToastUtils.toast("请先初始化");
        }
    }

    public void createRole(View v){
        if (isLogin){
            setText("创角报送");
            FastSdk.report(EventType.CreateRole, getPlayerInfo());
        }else{
            ToastUtils.toast("请先登录");
        }
    }

    public void enterSever(View v){
        if (isLogin){
            setText("进服报送");
            FastSdk.report(EventType.EnterServer, getPlayerInfo());
        }else{
            ToastUtils.toast("请先登录");
        }
    }

    public void levelUp(View v){
        if (isLogin){
            setText("升级报送");
            FastSdk.report(EventType.LevelUp, getPlayerInfo());
        }else{
            ToastUtils.toast("请先登录");
        }
    }

    public void customTrack(View v){
        if (isLogin){
            setText("自定义报送");
            FastSdk.report(EventType.CustomerAction, getPlayerInfo());
        }else{
            ToastUtils.toast("请先初始化");
        }
    }

    public void logout(View v){
        if (isLogin){
            setText("调用登出");
            FastSdk.logout();
        }else{
            ToastUtils.toast("请先登录");
        }
    }

    public void getPriceInfo(View v){
        if (isLogin){
            setText("查询商品");
            FastSdk.queryGoodsInfo();
        }else{
            ToastUtils.toast("请先登录");
        }
    }

    public void doPay(View v){
        if (isLogin){
            int amount = 1;//单位：分
            setText("调用支付");
            FastSdk.pay(this, getPayParams(amount));
        }else{
            ToastUtils.toast("请先登录");
        }
    }

    public void exit(View v){
        setText("调用退出");
        FastSdk.exit();
    }

    public void share(View v){
        ShareActivity.start(this);
    }
    private PlayerInfo getPlayerInfo(){
        PlayerInfo playerInfo = new PlayerInfo();
        playerInfo.setRoleId("1235761");//角色唯一标识id
        playerInfo.setRoleName("昵称2");
        playerInfo.setRoleLevel("11");
        playerInfo.setZoneId("100");
        playerInfo.setZoneName("华东大区");
        playerInfo.setServerId("100");
        playerInfo.setServerName("大唐战机");
        playerInfo.setBalance("66");
        playerInfo.setVip("1");
        playerInfo.setPartyName("帮派名称");
        playerInfo.setClassField("aaaa");
        playerInfo.setExtendAction("aaaatest");
        playerInfo.setExtra("a:arm,b:bom");//扩展信息,格式:key:value,key:value
        playerInfo.setPhylum("1");
        return playerInfo;
    }

    private PayParams getPayParams(int amount){
        PayParams payParams = new PayParams();
        payParams.setItemId("aaa.bbb.cc");//商品，要保证游戏内各个商品唯一（可以不传）
        //ItemName要求：这些特殊符号都不要有: + % # “ & / ? $ ^ *:) \ < > , |。否则会造成某些渠道支付报错如：华为渠道
        payParams.setItemName("钻石");//购买物品名称
        payParams.setAmount(amount);//金额(分)
        payParams.setCount(1);//购买商品数量，例如50元宝，传值50
        payParams.setCallbackInfo("callbackInfo");//扩展信息，回调时原样返回,因为各渠道回调参数限制不一致。回调参数暂时只支持长度50。callBackInfo中不要使用这些符号：“|”、“=”、“+”、“/”。
        payParams.setCurrency("CNY");//国内可不传或CNY
        return payParams;
    }
    private void setText(String temp){
        str = str + temp + "\n";
        textview.setText(str);
    }
}